# qcrandom
## Overview
qcrandom is a python library which provides easy way to generate random numbers on quantum computers. Quantum computers allow us to generate truly random numbers.

## Setup
Setup instructions are avaliable [here](https://github.com/pk8868/qc-random/wiki/Setup).

## Learn
Check out our [Wiki page](https://github.com/pk8868/qc-random/wiki)!

## Any problems?
If you find a bug, feel free to post an [issue](https://github.com/pk8868/qc-random/issues)!